/**
 * Mersenne Twister originally borrowed from https://gist.github.com/banksean/300494.
 */
export declare class MersenneTwister {
    /**
     * Period parameter N.
     */
    private N;
    /**
     * Period parameter M.
     */
    private M;
    /**
     * Constant vector A.
     */
    private MATRIX_A;
    /**
     * Most significant W-R bits.
     */
    private UPPER_MASK;
    /**
     * Least significant R bits.
     */
    private LOWER_MASK;
    /**
     * Private class member to store the state vector.
     */
    private mt;
    /**
     * The index of the state vector. An mti value of N + 1 means mt[N] is not initialized.
     */
    private mti;
    constructor(seed?: number);
    /**
     * Initializes mt[N] with a seed.
     * @param {number} s The numeric seed.
     */
    private _init_genrand;
    /**
     * Generates a random number on [0,0xffffffff]-interval.
     * @return {number} A randomnly generated 32-bit integer.
     */
    genrand_int32(): number;
    /**
     * Generates a random number on [0,0x7fffffff]-interval.
     * @return {number} A randomnly generated 31-bit integer.
     */
    genrand_int31(): number;
    /**
     * Generates a random number on [0,1]-real-interval.
     * @return {number} A randomnly generated number between zero and one inclusive.
     */
    genrand_real1(): number;
    /**
     * Generates a random number on [0,1)-real-interval.
     * @return {number} A randomnly generated number between zero and one,
     * inclusive of zero, exclusive of one.
     */
    random(): number;
    /**
     * Generates a random number on (0,1)-real-interval.
     * @return {number} A randomnly generated number between zero and one exclusive.
     */
    genrand_real3(): number;
    /**
     * Generates a random number on [0,1) with 53-bit resolution.
     * @return {number} A randomnly generated number between zero and one,
     * inclusive.of zero, exclusive of one, with 53-bit resolution.
     */
    genrand_res53(): number;
}
